%let progname = ebv010.sas;
* xref: ebv009.sas ... ebv011.sas
* input:    e008 .. e011
* output:   e012.dat
* does: Summaries of efficiencies
        Output a raw data file
********************************************************************;
libname X "";
filename OUT "e012.dat";
********************************************************************;
data E9A;
  set  X.E009;
  if (dist_t = dist_w);
  dist = dist_t;
  drop dist_t dist_w;
  run;

data E9B;
  set  X.E009;
  if (dist_w = 2);
  dist = dist_t;
  ae_ort2_lor = ae_ort_lor;  * eff(ORTH) under working model 2;
  keep dist pi rho  ae_ort2_lor;
  run;


data A B;
  merge X.E008 (in=in8)  E9A (in=in9a)   E9B (in=in9b)
        X.E010 (in=in10) X.E011 (in=in11) ;
    by dist pi rho;
  if in8 and in9a and in9b and in10 and in11;
  cov = pi*(1-pi)*rho;
  lor = (pi*pi+cov)*((1-pi)*(1-pi)+cov);
  lor = lor / (pi*(1-pi)-cov)**2;
  lor = log(lor); * log odds ratio;
  drop cov;
  file OUT;
  put
       dist pi rho ae_alr_pi    ae_alr_lor
                   ae_ort_pi    ae_ort_lor
                                ae_ort2_lor
                   ae_p88_pi    ae_p88_lor
                   ae_pl_pi     ae_pl_lor
                   ae_gee2d_pi  ae_gee2d_lor
                   ae_ch_pi     ae_ch_lor
                   ae_kn_pi     ae_kn_lor
  ;
  output A;
  r = round(rho*100);
  p = round(pi *100);
  if (p=10) and (r in (0, 5, 10, 15, 30, 60, 90)) then output B;
  drop p r;
  run;

proc means      data=A;
  var
    ae_alr_pi
    ae_p88_pi
    ae_ort_pi
    ae_pl_pi
    ae_gee2d_pi
    ae_ch_pi
    ae_kn_pi
  ;
  by dist;
  run;


proc means      data=A;
  var
    ae_alr_lor
    ae_p88_lor
    ae_ort_lor
    ae_ort2_lor
    ae_pl_lor
    ae_gee2d_lor
    ae_ch_lor
    ae_kn_lor
  ;
  by dist;
  run;

proc print data=A noobs;
  var
    pi rho lor
    ae_alr_pi
    ae_p88_pi
    ae_ort_pi
    ae_ort2_pi
    ae_pl_pi
    ae_gee2d_pi
    ae_ch_pi
    ae_kn_pi
  ;
  id dist;
  run;

proc print data=A noobs;
  var
    pi rho lor
    ae_alr_lor
    ae_p88_lor
    ae_ort_lor
    ae_ort2_lor
    ae_pl_lor
    ae_gee2d_lor
    ae_ch_lor
    ae_kn_lor
  ;
  id dist;


proc sort  data=B; by dist rho; run;

proc print data=B noobs;
  var
    pi rho lor
    ae_alr_lor ae_p88_lor ae_ort_lor ae_ort2_lor ae_pl_lor ae_gee2d_lor
    ae_ch_lor ae_kn_lor
  ;
  id dist;
  run;


data C;
  set B;
  ort_alr_lor = ae_ort_lor / ae_alr_lor;
  ort_alr_rho = ae_ort_rho / ae_alr_rho;
  ort_ch_rho = ae_ort_rho / ae_ch_rho;
  ort_ch_lor = ae_ort_lor / ae_ch_lor;
  ort_kn_lor = ae_ort_lor / ae_kn_lor;
  ort_kn_rho = ae_ort_rho / ae_kn_rho;
  ort_gee2d_rho = ae_ort_rho / ae_gee2d_rho;
  ort_gee2d_lor = ae_ort_lor / ae_gee2d_lor;
  run;

proc print data=C noobs;
  var
    pi rho lor
    ort_alr_lor
    ort_alr_rho
    ort_ch_rho
    ort_ch_lor
    ort_kn_rho
    ort_kn_lor
    ort_gee2d_rho
    ort_gee2d_lor
  ;
  id dist;
  run;



data D;
  set A;
  if (pi = 0.2);
  if (rho= 0.30);
  run;

proc print data=D noobs;
  var
    pi rho
    ae_alr_pi
    ae_pl_pi
    ae_ch_pi
    ae_kn_pi
  ;
  by dist;
  run;


proc print data=D noobs;
  var
    pi rho
    ae_alr_lor
    ae_p88_lor
    ae_ort_lor
    ae_ort2_lor
    ae_gee2d_lor
    ae_ch_lor
    ae_kn_lor
  ;
  by dist;
  run;



data E;
  set A;
  d1 = ae_alr_lor - ae_kn_lor;
  d2 = ae_alr_lor - ae_pl_lor;
  d3 = ae_alr_lor - ae_pl_lor;
  d4 = ae_ch_pi   - ae_kn_pi ;
  run;

proc means data=E; var d1-d4; run;

data F;
  set A;
  if (pi=0.2);
  if (rho=0 or rho=0.001);
  run;

proc print data=F noobs;
  var
    pi rho
    ae_alr_lor
    ae_p88_lor
    ae_ort_lor
    ae_ort2_lor
    ae_gee2d_lor
    ae_ch_lor
    ae_kn_lor
  ;
  by dist;
  run;

